summaryrefslogtreecommitdiffstats
path: root/hl/src/H5DS.c
diff options
context:
space:
mode:
authorPedro Vicente Nunes <pvn@hdfgroup.org>2006-04-12 21:21:38 (GMT)
committerPedro Vicente Nunes <pvn@hdfgroup.org>2006-04-12 21:21:38 (GMT)
commitbc66efc788bc77c9c133a9fc3cc29e26fa659bab (patch)
treed94f011f1813b4bc479a74f29048418c83f86d02 /hl/src/H5DS.c
parent3dfec8d73b65c5c715581e41844e075b84e8f581 (diff)
downloadhdf5-bc66efc788bc77c9c133a9fc3cc29e26fa659bab.zip
hdf5-bc66efc788bc77c9c133a9fc3cc29e26fa659bab.tar.gz
hdf5-bc66efc788bc77c9c133a9fc3cc29e26fa659bab.tar.bz2
[svn-r12229] Purpose:
new feature Description: 1) separated the HL library into "public" and "private" header files, with the same caracteristics as the basic library 2) added the public headers to hdf5.h (with a conditional include macro, defined in configure.in) 3) added the path to HL in all Makefile.am 's , because of the inclusion in hdf5.h Solution: Platforms tested: linux 32, 64 AIX solaris with fortran and c++ (one packet table example fails) Misc. update:
Diffstat (limited to 'hl/src/H5DS.c')
-rw-r--r--hl/src/H5DS.c27
1 files changed, 13 insertions, 14 deletions
diff --git a/hl/src/H5DS.c b/hl/src/H5DS.c
index 5d5001d..0c8c201 100644
--- a/hl/src/H5DS.c
+++ b/hl/src/H5DS.c
@@ -12,12 +12,11 @@
* access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-#include "H5private.h"
-#include "H5DS.h"
-#include "H5LT.h"
#include <stdlib.h>
-#include "H5IM.h"
-#include "H5TB.h"
+#include "H5DSprivate.h"
+#include "H5LTprivate.h"
+#include "H5IMprivate.h"
+#include "H5TBprivate.h"
@@ -30,7 +29,7 @@
* If DIMNAME is specified, then an attribute called NAME is created,
* with the value DIMNAME.
*
* Return: Success: SUCCESS, Failure: FAIL
*
* Programmer: pvn@ncsa.uiuc.edu
*
@@ -86,7 +85,7 @@ herr_t H5DSset_scale(hid_t dsid,
return FAIL;
}
- return SUCCESS;
+ return SUCCEED;
}
@@ -99,7 +98,7 @@ herr_t H5DSset_scale(hid_t dsid,
* REFERENCE_LIST attributes.
*
* Return:
- * Success: SUCCESS
+ * Success: SUCCEED
* Failure: FAIL
*
* Fails if: Bad arguments
@@ -540,7 +539,7 @@ herr_t H5DSattach_scale(hid_t did,
return FAIL;
}
- return SUCCESS;
+ return SUCCEED;
/* error zone, gracefully close */
out:
@@ -560,7 +559,7 @@ out:
* DIMENSION_LIST and REFERENCE_LIST attributes.
*
* Return:
- * Success: SUCCESS
+ * Success: SUCCEED
* Failure: FAIL
*
* Fails if: Bad arguments
@@ -901,7 +900,7 @@ herr_t H5DSdetach_scale(hid_t did,
}
- return SUCCESS;
+ return SUCCEED;
/* error zone, gracefully close */
out:
@@ -1287,7 +1286,7 @@ herr_t H5DSiterate_scales(hid_t did,
return FAIL;
if (has_dimlist == 0)
- return SUCCESS;
+ return SUCCEED;
else if (has_dimlist == 1 )
{
@@ -1385,7 +1384,7 @@ out:
*
* Purpose: Set label for the dimension IDX of dataset DID to the value LABEL
*
* Return: Success: SUCCESS, Failure: FAIL
*
* Programmer: pvn@ncsa.uiuc.edu
*
@@ -1533,7 +1532,7 @@ herr_t H5DSset_label(hid_t did,
free(buf);
}
- return SUCCESS;
+ return SUCCEED;
/* error zone, gracefully close */
out:
@@ -30,7 +29,7 @@
* with the value DIMNAME.
*
- * Return: Success: SUCCESS, Failure: FAIL
+ * Return: Success: SUCCEED, Failure: FAIL
*
* Programmer: pvn@ncsa.uiuc.edu
@@ -1385,7 +1384,7 @@ out:
* Purpose: Set label for the dimension IDX of dataset DID to the value LABEL
*
- * Return: Success: SUCCESS, Failure: FAIL
+ * Return: Success: SUCCEED, Failure: FAIL
*
* Programmer: pvn@ncsa.uiuc.edu